==> datasets-1.4.1.tar.gz: datasets-1.4.1/datasets/ms_terms/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- expert-generated
languages:
- af
- sq
- am
- ar
- hy
- as
- az
- bn
- other-bn-india
- eu
- be
- bs
- other-bs-latin
- bg
- ca
- ku
- chr
- zh
- other-zh-Hant_HK
- other-zh-Hant_TW
- hr
- cs
- da
- prs
- nl
- en
- et
- fil
- fi
- fr
- other-fr_CA
- gl
- ka
- de
- el
- gu
- ha
- he
- hi
- hu
- is
- ig
- id
- iu
- ga
- xh
- zu
- it
- ja
- quc
- kn
- kk
- km
- rw
- swh
- knn
- ko
- ky
- lo
- lv
- lt
- lb
- mk
- other-ms-brunei (Brunei Darus.)
- ms
- ml
- mt
- mi
- mr
- mn
- ne
- nb
- nn
- ory
- pst
- fa
- pl
- other-pt-br
- pt
- pa
- pa
- qu
- ro
- ru
- gd
- other-sr-bih
- sr
- other-sr-latin
- st
- tn
- sd
- si
- sk
- sl
- es
- other-es-MX
- sv
- tg
- ta
- tt
- te
- th
- ti
- tr
- tk
- uk
- ur
- ug
- uz
- other-valencian
- vi
- guc
- cy
- wo
- yo
licenses:
- ms-pl
multilinguality:
- multilingual
- translation
size_categories:
- 10K<n<100K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
---

# Dataset Card for [ms_terms]

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-instances)
  - [Data Splits](#data-instances)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:**

[Microsoft Terminology Collection](https://www.microsoft.com/en-us/language/terminology)

- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

The Microsoft Terminology Collection can be used to develop localized versions of applications that integrate with Microsoft products. It can also be used to integrate Microsoft terminology into other terminology collections or serve as a base IT glossary for language development in the nearly 100 languages available. Terminology is provided in .tbx format, an industry standard for terminology exchange.

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

Nearly 100 Languages.

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]

### Contributions

Thanks to [@leoxzhao](https://github.com/leoxzhao), [@lhoestq](https://github.com/lhoestq) for adding this dataset.

==> datasets-1.18.0.tar.gz: datasets-1.18.0/datasets/ms_terms/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- expert-generated
languages:
- af
- sq
- am
- ar
- hy
- as
- az
- bn
- other-bn-india
- eu
- be
- bs
- other-bs-latin
- bg
- ca
- ku
- chr
- zh
- other-zh-Hant_HK
- other-zh-Hant_TW
- hr
- cs
- da
- prs
- nl
- en
- et
- fil
- fi
- fr
- other-fr_CA
- gl
- ka
- de
- el
- gu
- ha
- he
- hi
- hu
- is
- ig
- id
- iu
- ga
- xh
- zu
- it
- ja
- quc
- kn
- kk
- km
- rw
- swh
- knn
- ko
- ky
- lo
- lv
- lt
- lb
- mk
- other-ms-brunei (Brunei Darus.)
- ms
- ml
- mt
- mi
- mr
- mn
- ne
- nb
- nn
- ory
- pst
- fa
- pl
- other-pt-br
- pt
- pa
- pa
- qu
- ro
- ru
- gd
- other-sr-bih
- sr
- other-sr-latin
- st
- tn
- sd
- si
- sk
- sl
- es
- other-es-MX
- sv
- tg
- ta
- tt
- te
- th
- ti
- tr
- tk
- uk
- ur
- ug
- uz
- other-valencian
- vi
- guc
- cy
- wo
- yo
licenses:
- ms-pl
multilinguality:
- multilingual
- translation
size_categories:
- 10K<n<100K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
paperswithcode_id: null
pretty_name: MsTerms
---

# Dataset Card for [ms_terms]

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:**

[Microsoft Terminology Collection](https://www.microsoft.com/en-us/language/terminology)

- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

The Microsoft Terminology Collection can be used to develop localized versions of applications that integrate with Microsoft products. It can also be used to integrate Microsoft terminology into other terminology collections or serve as a base IT glossary for language development in the nearly 100 languages available. Terminology is provided in .tbx format, an industry standard for terminology exchange.

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

Nearly 100 Languages.

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]

### Contributions

Thanks to [@leoxzhao](https://github.com/leoxzhao), [@lhoestq](https://github.com/lhoestq) for adding this dataset.
